%bcond_with docs

Summary:		The Oil Run-time Compiler
Name:			orc
Version:		0.4.33
Release:		5%{?dist}
License:		BSD
URL:			https://gstreamer.freedesktop.org/modules/orc.html
Source0:		http://gstreamer.freedesktop.org/src/orc/%{name}-%{version}.tar.xz
# https://jvn.jp/en/jp/JVN02030803/
# https://gitlab.freedesktop.org/gstreamer/orc/-/merge_requests/191.patch
Patch0000:              CVE-2024-40897.patch

BuildRequires:	gcc meson >= 0.47.0
%if %{with docs}
BuildRequires:	gtk-doc
%endif

%description
Orc is a library and set of tools for compiling and executing
very simple programs that operate on arrays of data.  The "language"
is a generic assembly language that represents many of the features
available in SIMD architectures, including saturated addition and
subtraction, and many arithmetic operations.

%if %{with docs}
%package doc
Summary:		Documentation for Orc
Requires:		%{name} = %{version}-%{release}
BuildArch:		noarch

%description doc
Documentation for Orc.
%endif

%package devel
Summary:		Development files and libraries for Orc
Requires:		%{name} = %{version}-%{release}
Requires:		%{name}-compiler
Requires:		pkgconfig

%description devel
This package contains the files needed to build packages that depend
on orc.

%package compiler
Summary:		Orc compiler
Requires:		%{name} = %{version}-%{release}
Requires:		pkgconfig

%description compiler
The Orc compiler, to produce optimized code.

%prep
%autosetup -p1

%build
%meson \
%if %{without docs}
  -D gtk_doc=disabled \
%endif
  -D default_library=shared 
%meson_build

%install
%meson_install

find %{buildroot}/%{_libdir} -name \*.a -delete
rm -rf %{buildroot}/%{_libdir}/orc

%check
%ifnarch ppc64le aarch64
%meson_test
%endif

%files
%license COPYING
%doc README
%{_libdir}/liborc-*.so.*
%{_bindir}/orc-bugreport

%if %{with docs}
%files doc
%doc %{_datadir}/gtk-doc/html/orc/
%endif

%files devel
%doc examples/*.c
%{_includedir}/%{name}-0.4/
%{_libdir}/liborc-*.so
%{_libdir}/pkgconfig/orc-0.4.pc
%{_libdir}/pkgconfig/orc-test-0.4.pc
%{_datadir}/aclocal/orc.m4

%files compiler
%{_bindir}/orcc

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.33-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.33-4
- Rebuilt for loongarch release

* Mon Jul 29 2024 rockerzhu <rockerzhu@tencent.com> - 0.4.33-3
- [Type] Security
- [Desc] Fix CVE-2024-40897

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.33-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 Wang Guodong <gordonwwang@tencent.com> - 0.4.33-1
- Upgrade to version 0.4.33

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.31-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.31-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Nov 23 2022 Xiaojie Chen <jackxjchen@tencent.com> - 0.4.31-1
- Initial build
